pub struct ApiError { /* private fields */ }Implementations
Sourceimpl ApiError
impl ApiError
pub fn new(message: impl Display, status_code: StatusCode) -> Self
pub fn status(&self) -> Result<StatusCode, InvalidStatusCode>
pub fn message(&self) -> &str
Sourcepub fn internal(message: impl AsRef<str>) -> Self
pub fn internal(message: impl AsRef<str>) -> Self
Create a one-off internal error with a string message exposed to the user.
Sourcepub fn internal_safe<E: Error + 'static>(
safe_msg: impl Display,
error: E,
) -> Self
pub fn internal_safe<E: Error + 'static>( safe_msg: impl Display, error: E, ) -> Self
Creates an internal error without exposing sensitive information to the user.
pub fn bad_request(error: impl Display) -> Self
pub fn forbidden(error: impl Display) -> Self
pub fn not_found(error: impl Display) -> Self