Module secrets
shuttle_
common
0.57.0
Module secrets
Module Items
Structs
In crate shuttle_
common
shuttle_common
Module
secrets
Structs

Secret
Wrapper type for secret values such as passwords or authentication keys.
Secret
Store
Store that holds all the secrets available to a deployment