pub struct Secret<T: Zeroize>(/* private fields */);Expand description
Wrapper type for secret values such as passwords or authentication keys.
Once wrapped, the inner value cannot leak accidentally, as both the std::fmt::Display and Debug
implementations cover up the actual value and only show the type.
If you need access to the inner value, there is an expose method.
To make sure nothing leaks after the Secret has been dropped, a custom Drop
implementation will zero-out the underlying memory.
Implementations